package cn.ezhizao.project.business.controller;

import cn.ezhizao.framework.logGing.SomeService;
import cn.ezhizao.framework.web.controller.BaseController;
import cn.ezhizao.framework.web.domain.AjaxResult;
import cn.ezhizao.project.business.domain.*;
import cn.ezhizao.project.business.service.*;
import cn.hutool.core.date.DateTime;
import io.swagger.annotations.Api;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;


@Api("智能仓储")
@RestController
@RequestMapping("/business/inboundOrder")
public class BizInboundOrderController extends BaseController {
    @Resource
    private IBizInboundOrderService bizInboundOrderService;
    @Resource
    private IBizInboundOrderDetailService bizInboundOrderDetailService;
    @Resource
    private IBizCertificateService bizCertificateService;
    @Resource
    private IBizTakeStockPeriodService bizTakeStockPeriodService;
    @Resource
    private IBizTaksStockLotService bizTaksStockLotService;

    /**
     * 库存推送
     *
     * @param bizInboundOrder
     * @return
     */
    @PostMapping("/warehousing")
    public AjaxResult warehousing(@RequestBody BizInboundOrder bizInboundOrder) {
        if (bizInboundOrder.getPalletCode() == null || bizInboundOrder.getPalletCode().isEmpty()) {
            return error("请输入托盘码");
        }
        // 根据托盘编码获取入库单列表
        List<BizInboundOrder> list = bizInboundOrderService.query().eq("transfer_code", bizInboundOrder.getPalletCode()).eq("is_all_inbound", 0).list();
        if (list.isEmpty()) {
            return error("没有找到托盘码对应入库单");
        }
        List<BizInboundOrderDetail> detailList = bizInboundOrderDetailService.query().in("inbound_order_id", list.isEmpty() ? Collections.singletonList(0L) : list.stream().map(BizInboundOrder::getId).collect(Collectors.toList())).list();
        List<BizCertificate> bizCertificateList = bizCertificateService.query().in("id",  detailList.isEmpty() ? Collections.singletonList(0L) : detailList.stream().map(BizInboundOrderDetail::getCertificateId).collect(Collectors.toList())).list();

        List<Map<String, Object>> inboundList = new ArrayList<>();
        list.forEach(l -> {
            Map<String, Object> map = new HashMap<>();
            map.put("palletCode", l.getTransferCode());
            map.put("inBoundCode", l.getInboundNumber());
            map.put("keeperCode", l.getStorageUserName());
            List<Map<String, Object>> datas = new ArrayList<>();
            detailList.stream().filter(v -> v.getInboundOrderId().equals(l.getId())).forEach(v -> {
                BizCertificate bizCertificate = bizCertificateList.stream().filter(t -> t.getId().equals(v.getCertificateId())).findFirst().orElse(null);
                Map<String, Object> t = new HashMap<String, Object>();
                t.put("packCode", v.getCertificateCode());
                t.put("batchCode", v.getLotCode());
                t.put("materialCode", l.getProductCode());
                t.put("qty", v.getInboundNum());
                t.put("customerCode", l.getCompanyCode());
                t.put("packDate", bizCertificate != null ? DateTime.of(bizCertificate.getPrintDate()).toString("yyyy-MM-dd") : null);
                datas.add(t);
            });
            map.put("datas", datas);
        });
        Map<String, Object> returnData = new HashMap<>();
        returnData.put("palletCode", bizInboundOrder.getPalletCode());
        returnData.put("packDatas", inboundList);
        return success(returnData);
    }

    /**
     * 上架
     */
    @PostMapping("/putAway")
    @Transactional
    public AjaxResult putAway(@RequestBody BizInboundOrder bizInboundOrder) {
        // 入参
        // "palletCode": "2410616" -- 托盘码
        // "inBoundCode": "EAS251644" --  入库单号
        // "packCode": "2521046861" -- 合格证编码
        if (bizInboundOrder.getPalletCode() == null || bizInboundOrder.getPalletCode().isEmpty()) {
            return error("请输入托盘码");
        }
        if (bizInboundOrder.getInBoundCode() == null || bizInboundOrder.getInBoundCode().isEmpty()) {
            return error("请输入入库单号");
        }
        if (bizInboundOrder.getPackCode() == null || bizInboundOrder.getPackCode().isEmpty()) {
            return error("请输入箱码");
        }
        List<BizInboundOrder> list = bizInboundOrderService.query().eq("inbound_number", bizInboundOrder.getInBoundCode()).list();
        if (list.isEmpty()) {
            // 返回入库单不存在错误
            return error("入库单不存在");
        }
        List<BizInboundOrderDetail> details = bizInboundOrderDetailService.query().in("inbound_order_id", list.stream().map( BizInboundOrder::getId).collect(Collectors.toList())).eq("certificate_code", bizInboundOrder.getPackCode()).list();
        if (details.isEmpty()) {
            // 返回合格证不存在错误
            return error("入库单对应箱码不存在");
        }
        details.forEach(l ->{
            l.setPalletCode(bizInboundOrder.getPalletCode());
            l.setIsInbound(1);
        });
        bizInboundOrderDetailService.updateBatchById(details);
        list.forEach(l ->{
            // 判断未入库明细数量是否大于0 假设大于0 则部分入库，否则全部入库
            long inboundNum =  bizInboundOrderDetailService.query().eq("inbound_order_id", l.getId()).eq("is_inbound", 0).count();
             if(inboundNum > 0){
                l.setIsAllInbound(0);
                l.setStatus("1");
            }else{
                l.setIsAllInbound(1);
                l.setStatus("2");
            }
        });
        bizInboundOrderService .updateBatchById(list);

        //添加异常处理，如果出现异常，则创建异常日志并正常返回
        try {

            //查找当天是否有盘点数据
            String nowDate = DateTime.now().toString("yyyy-MM-dd");
            String startDate = nowDate + " 00:00:00";
            String endDate = nowDate + " 23:59:59"; //

            List<BizTakeStockPeriod> periods = bizTakeStockPeriodService.query()
                    .ge("start_time", startDate) // 大于等于开始时间
                    .le("start_time", endDate)   // 小于等于结束时间
                    .eq("deleted", 0)
                    .orderByDesc("create_time")
                    .list();

//            List<BizTakeStockPeriod> periods = bizTakeStockPeriodService.query().eq("start_time", DateTime.now().toString("yyyy-MM-dd")).orderByDesc("create_time").list();
            //如果当天有盘点数据，根据details入库单明细的批次id，将periods当天最新创建的盘点数据中的入库字段设为1，表示该批次已入库
            if (!periods.isEmpty()) {
                //拿到入库单明细的批次id进行去重
                List<Long> uniqueLotIdList = details.stream().map(BizInboundOrderDetail::getLotId).distinct().collect(Collectors.toList());

                BizTaksStockLot taksStockLot = new BizTaksStockLot();
                taksStockLot.setTakeStockPeriodId(periods.get(0).getId());
                taksStockLot.setLotIdsForInbound(uniqueLotIdList);

                //根据盘点id和批次id修改盘点明细中批次的入库状态
                bizTaksStockLotService.updateBatchByIdsForInbound(taksStockLot);

            }
        } catch (Exception e) {
            SomeService service=new SomeService();
            service.someMethod("上架修改盘点数据异常："+e.getMessage()+"。 入库单号："+bizInboundOrder.getInBoundCode());
            service.onDestroy();
        }

        return success("更新成功");
    }
}
