package cn.ezhizao.project.system.service;

import cn.ezhizao.framework.aspectj.lang.annotation.DataScope;
import cn.ezhizao.project.system.domain.SysUser;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;
import java.util.List;

/**
 * 用户 业务层
 *
 * @author ruoyi
 */
public interface ISysUserService {

    /**
     * 根据用户名获取用户信息
     *
     * @param userName 用户编码
     * @return 用户信息
     */
    SysUser getUserByCode(String userName);

    List<SysUser> getList();

    List<SysUser> selectEmployeeList(SysUser sysUser);
    String checkUserNameUnique(SysUser user);
    String checkPhoneUnique(SysUser user);
    String checkEmailUnique(SysUser user);
    int insertUser(SysUser user);
    void checkUserAllowed(SysUser user);
    int updateUser(SysUser user);
    int deleteUserByIds(List<Long> userIds);
    List<SysUser> selectUserListByIds(List<Long> userIds);

    /**
     * 校验用户是否有数据权限
     *
     * @param userId 用户id
     */
    void checkUserDataScope(Long userId);

    @DataScope(deptAlias = "d", userAlias = "u")
    List<SysUser> selectUserList(SysUser user);

    SysUser selectUserByUserNameAndTenantId(@NotBlank(message = "用户账号不能为空") @Size(min = 0, max = 30, message = "用户账号长度不能超过30个字符") String userName, Long tenantId);
}
